.. _resources-index:

*******************
 External Resources
*******************


===================
 Books and Chapters
===================

* `Matplotlib for Python Developers 
  <http://www.packtpub.com/matplotlib-python-development/book?mid/171109cna1h>`_ 
  by Sandro Tosi

* `Matplotlib chapter <http://www.aosabook.org/en/matplotlib.html>`_ 
  by John Hunter and Michael Droettboom in The Architecture of Open Source 
  Applications

* `Graphics with Matplotlib 
  <http://physics.nmt.edu/~raymond/software/python_notes/paper004.html>`_ 
  by David J. Raymond

=======
 Videos
=======

* `Getting started with Matplotlib 
  <http://showmedo.com/videotutorials/video?name=7200090&fromSeriesID=720>`_ 
  by `unpingco <http://showmedo.com/videotutorials/?author=6237>`_

* `Plotting with matplotlib <http://www.youtube.com/watch?v=P7SVi0YTIuE>`_ 
  by Mike Müller 

* `Introduction to NumPy and Matplotlib 
  <http://www.youtube.com/watch?v=3Fp1zn5ao2M&feature=plcp>`_ by Eric Jones

* `Anatomy of Matplotlib
  <https://conference.scipy.org/scipy2013/tutorial_detail.php?id=103>`_
  by Benjamin Root

==========
 Tutorials
==========

* `Matplotlib tutorial <http://www.loria.fr/~rougier/teaching/matplotlib/>`_ 
  by Nicolas P. Rougier

* `Anatomy of Matplotlib - IPython Notebooks
  <https://github.com/WeatherGod/AnatomyOfMatplotlib>`_
  by Benjamin Root

